require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_agent',
  dscmeta_resource_friendly_name: 'Agent',
  dscmeta_resource_name: 'Intigua_Agent',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Intigua',
  dscmeta_module_version: '1.0.0.9',
  docs: 'The DSC Agent resource type.
         Automatically generated from version 1.0.0.9',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_agentname: {
      type: 'String',
      desc: 'Agent name.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_limitmanagedagentmemoryconsumptionto: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Limit managed agent memory consumption to.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_keepmanagedagentcpuutilizationunder: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Keep managed agent CPU utilization under.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Ensure.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_intigualoglevel: {
      type: "Optional[Enum['Trace', 'Debug', 'Info', 'Warning', 'Error', 'Fatal']]",
      desc: 'Intigua log level.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablememoryandcpucontrol: {
      type: 'Optional[Boolean]',
      desc: 'Enable memory and CPU control.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumnumberofautostartsinaday: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Maximum number of auto starts in a day.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_agentpath: {
      type: 'String',
      desc: 'Agent path.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_agentparameters: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Agent parameters.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_automaticallystartagentuponfailure: {
      type: 'Optional[Boolean]',
      desc: 'Automatically start agent upon failure.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
